"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.cleanStyle = cleanStyle;
exports.getStylesFromShikiTheme = getStylesFromShikiTheme;
var _cssToReactNative = _interopRequireDefault(require("css-to-react-native"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const ALLOWED_STYLE_PROPERTIES = {
  color: true,
  background: true,
  backgroundColor: true,
  fontWeight: true,
  fontStyle: true,
  textDecoration: true
};
function parseFontStyle(fontStyle) {
  if (!fontStyle) return {};
  const styles = {};
  if (fontStyle.includes('italic')) styles.fontStyle = 'italic';
  if (fontStyle.includes('bold')) styles.fontWeight = 'bold';
  return styles;
}
function getStylesFromShikiTheme(theme) {
  const styles = {
    root: {
      backgroundColor: theme.bg || theme.colors?.['editor.background'] || '#000000',
      color: theme.fg || theme.colors?.['editor.foreground'] || '#ffffff'
    }
  };

  // Convert theme settings to styles
  theme.settings?.forEach(setting => {
    if (setting.scope && setting.settings) {
      const scopes = Array.isArray(setting.scope) ? setting.scope : [setting.scope];
      const fontStyles = parseFontStyle(setting.settings.fontStyle);
      scopes.forEach(scope => {
        styles[scope] = cleanStyle({
          color: setting.settings.foreground,
          backgroundColor: setting.settings.background,
          ...fontStyles
        });
      });
    }
  });
  return styles;
}
function cleanStyle(style) {
  const styles = Object.entries(style).filter(([key, value]) => ALLOWED_STYLE_PROPERTIES[key] && value !== undefined).map(([key, value]) => [key, value]);
  return (0, _cssToReactNative.default)(styles);
}
//# sourceMappingURL=style.js.map